List<CategoryPackWithSet> categoryPackWithSetListFromJson(dynamic str) =>
    List<CategoryPackWithSet>.from(
        str.map((x) => CategoryPackWithSet.fromJson(x)));

CategoryPackWithSet categoryPackWithSetFromJson(dynamic str) =>
    (CategoryPackWithSet.fromJson(str));

class CategoryPackWithSet {
  late final List<Pack> pack;
  late final int? currentPage;
  late final int? totalPages;
  late final int? count;
  late final String sTypename;

  CategoryPackWithSet(
      {required this.pack,
      required this.currentPage,
      required this.totalPages,
      required this.count,
      required this.sTypename});

  CategoryPackWithSet.fromJson(Map<String, dynamic> json) {
    if (json['pack'] != null) {
      pack = [];
      json['pack'].forEach((v) {
        pack.add(new Pack.fromJson(v));
      });
    }
    currentPage = json['currentPage'];
    totalPages = json['totalPages'];
    count = json['count'];
    sTypename = json['__typename'];
  }
}

class Pack {
  late final String sId;
  late final String? packSKU;
  late final int? moq;
  late final List<PackImages> packImages;
  late final String? packName;
  late final String? packVariant;
  late final HeadSetInformation? headSetInformation;
  late final bool? isOutofstock;
  late final String sTypename;

  Pack(
      {required this.sId,
      required this.packSKU,
      required this.moq,
      required this.packImages,
      required this.packName,
      required this.packVariant,
      required this.headSetInformation,
      required this.isOutofstock,
      required this.sTypename});

  Pack.fromJson(Map<String, dynamic> json) {
    sId = json['_id'];
    packSKU = json['packSKU'];
    moq = json['moq'];
    if (json['packImages'] != null) {
      packImages = [];
      json['packImages'].forEach((v) {
        packImages.add(new PackImages.fromJson(v));
      });
    }
    packName = json['packName'];
    packVariant = json['packVariant'];
    headSetInformation = json['headSetInformation'] != null
        ? new HeadSetInformation.fromJson(json['headSetInformation'])
        : null;
    isOutofstock = json['isOutofstock'];
    sTypename = json['__typename'];
  }
}

class PackImages {
  late final String? packImageName;
  late final String sTypename;

  PackImages({required this.packImageName, required this.sTypename});

  PackImages.fromJson(Map<String, dynamic> json) {
    packImageName = json['packImageName'];
    sTypename = json['__typename'];
  }
}

class HeadSetInformation {
  late final int? setPrice;
  late final int? setQuantity;
  late final String sTypename;

  HeadSetInformation(
      {required this.setPrice,
      required this.setQuantity,
      required this.sTypename});

  HeadSetInformation.fromJson(Map<String, dynamic> json) {
    setPrice = json['setPrice'];
    setQuantity = json['setQuantity'];
    sTypename = json['__typename'];
  }
}

ProductList productListFromJson(dynamic str) => (ProductList.fromJson(str));

class ProductList {
  late final List<Product>? product;
  late final int? currentPage;
  late final int? totalPages;
  late final int? count;
  late final String? sTypename;

  ProductList(
      {required this.product,
      required this.currentPage,
      required this.totalPages,
      required this.count,
      required this.sTypename});

  ProductList.fromJson(Map<String, dynamic> json) {
    if (json['product'] != null) {
      product = <Product>[];
      json['product'].forEach((v) {
        product!.add(new Product.fromJson(v));
      });
    }
    currentPage = json['currentPage'];
    totalPages = json['totalPages'];
    count = json['count'];
    sTypename = json['__typename'];
  }

  Map<String, dynamic> toJson() {
    final Map<String, dynamic> data = new Map<String, dynamic>();
    if (this.product != null) {
      data['product'] = this.product!.map((v) => v.toJson()).toList();
    }
    data['currentPage'] = this.currentPage;
    data['totalPages'] = this.totalPages;
    data['count'] = this.count;
    data['__typename'] = this.sTypename;
    return data;
  }
}

class Product {
  late final String? sId;
  late final String? productId;
  late final String? name;
  late final String? description;
  late final String? imageId;
  late final String? type;
  late final int? moq;
  late final bool? isOutofstock;
  late final bool? isMultiple;
  late final Price? price;
  late final List<Images>? images;
  late final String? sTypename;

  Product(
      {required this.sId,
      required this.productId,
      required this.name,
      required this.description,
      required this.imageId,
      required this.type,
      required this.moq,
      required this.isOutofstock,
      required this.isMultiple,
      required this.price,
      required this.images,
      required this.sTypename});

  Product.fromJson(Map<String, dynamic> json) {
    sId = json['_id'];
    productId = json['productId'];
    name = json['name'];
    description = json['description'];
    imageId = json['imageId'];
    type = json['type'];
    moq = json['moq'];
    isOutofstock = json['isOutofstock'];
    isMultiple = json['isMultiple'];
    price = json['price'] != null ? new Price.fromJson(json['price']) : null;
    if (json['images'] != null) {
      images = <Images>[];
      json['images'].forEach((v) {
        images!.add(new Images.fromJson(v));
      });
    }
    sTypename = json['__typename'];
  }

  Map<String, dynamic> toJson() {
    final Map<String, dynamic> data = new Map<String, dynamic>();
    data['_id'] = this.sId;
    data['productId'] = this.productId;
    data['name'] = this.name;
    data['description'] = this.description;
    data['imageId'] = this.imageId;
    data['type'] = this.type;
    data['moq'] = this.moq;
    data['isOutofstock'] = this.isOutofstock;
    data['isMultiple'] = this.isMultiple;
    if (this.price != null) {
      data['price'] = this.price!.toJson();
    }
    if (this.images != null) {
      data['images'] = this.images!.map((v) => v.toJson()).toList();
    }
    data['__typename'] = this.sTypename;
    return data;
  }
}

class Price {
  late final double? sellingPrice;
  late final double? mrp;
  late final double? discount;
  late final double? minPrice;
  late final double? maxPrice;
  late final String? type;
  late final bool? isSamePrice;
  late final String? sTypename;

  Price(
      {required this.sellingPrice,
      required this.mrp,
      required this.discount,
      required this.minPrice,
      required this.maxPrice,
      required this.type,
      required this.isSamePrice,
      required this.sTypename});

  Price.fromJson(Map<String, dynamic> json) {
    sellingPrice = json['sellingPrice'].toDouble();
    mrp = json['mrp'].toDouble();
    discount = json['discount'] != null ? json['discount'].toDouble() : 0;
    minPrice = json['minPrice'].toDouble();
    maxPrice = json['maxPrice'].toDouble();
    type = json['type'];
    isSamePrice = json['isSamePrice'];
    sTypename = json['__typename'];
  }

  Map<String, dynamic> toJson() {
    final Map<String, dynamic> data = new Map<String, dynamic>();
    data['sellingPrice'] = this.sellingPrice;
    data['mrp'] = this.mrp;
    data['discount'] = this.discount;
    data['minPrice'] = this.minPrice;
    data['maxPrice'] = this.maxPrice;
    data['type'] = this.type;
    data['isSamePrice'] = this.isSamePrice;
    data['__typename'] = this.sTypename;
    return data;
  }
}

class Images {
  late final String? imageName;
  late final int? position;
  late final String? sTypename;

  Images(
      {required this.imageName,
      required this.position,
      required this.sTypename});

  Images.fromJson(Map<String, dynamic> json) {
    imageName = json['imageName'];
    position = json['position'];
    sTypename = json['__typename'];
  }

  Map<String, dynamic> toJson() {
    final Map<String, dynamic> data = new Map<String, dynamic>();
    data['imageName'] = this.imageName;
    data['position'] = this.position;
    data['__typename'] = this.sTypename;
    return data;
  }
}

ProductDetails productDetailsFromJson(dynamic str) =>
    (ProductDetails.fromJson(str));

class ProductDetails {
  late final String? sId;
  late final bool? isMultiple;
  late final List<CategoryIds>? categoryIds;
  late final String? imageId;
  late final String? productId;
  late final String? name;
  late final String? description;

  late final dynamic? details;
  late final dynamic? packVariant;
  late final int? moq;
  late final bool? isOutofstock;
  late final String? type;
  late final List<dynamic>? skuIds;
  late final List<dynamic>? children;
  late final Price? price;
  late final List<VariantTypes>? variantTypes;
  late final List<Images>? images;
  late final List<MergeAttribute>? mergeAttribute;
  late final dynamic? filterAttribute;
  late final String? sTypename;
  late final String? skuId;

  ProductDetails(
      {required this.sId,
      required this.isMultiple,
      required this.categoryIds,
      required this.imageId,
      required this.productId,
      required this.name,
      required this.description,
      required this.details,
      required this.packVariant,
      required this.moq,
      required this.isOutofstock,
      required this.type,
      required this.skuIds,
      required this.children,
      required this.price,
      required this.variantTypes,
      required this.images,
      required this.mergeAttribute,
      required this.filterAttribute,
      required this.sTypename,
      required this.skuId});

  ProductDetails.fromJson(Map<String, dynamic> json) {
    sId = json['_id'];
    isMultiple = json['isMultiple'];
    if (json['categoryIds'] != null) {
      categoryIds = <CategoryIds>[];
      json['categoryIds'].forEach((v) {
        categoryIds!.add(new CategoryIds.fromJson(v));
      });
    }
    imageId = json['imageId'];
    productId = json['productId'];
    name = json['name'];
    description = json['description'];

    details = json['details'];
    packVariant = json['packVariant'];
    moq = json['moq'];
    skuId = json['skuId'];
    isOutofstock = json['isOutofstock'];
    type = json['type'];
    if (json['skuIds'] != null) {
      skuIds = <Null>[];
      json['skuIds'].forEach((v) {
        skuIds!.add(v);
      });
    }
    if (json['children'] != null) {
      children = <Null>[];
      json['children'].forEach((v) {
        children!.add(v);
      });
    }
    price = json['price'] != null ? new Price.fromJson(json['price']) : null;
    if (json['variantTypes'] != null) {
      variantTypes = <VariantTypes>[];
      json['variantTypes'].forEach((v) {
        variantTypes!.add(VariantTypes.fromJson(v));
      });
    }
    if (json['images'] != null) {
      images = <Images>[];
      json['images'].forEach((v) {
        images!.add(new Images.fromJson(v));
      });
    }
    if (json['mergeAttribute'] != null) {
      mergeAttribute = <MergeAttribute>[];
      json['mergeAttribute'].forEach((v) {
        mergeAttribute!.add(new MergeAttribute.fromJson(v));
      });
    }
    filterAttribute = json['filterAttribute'];
    sTypename = json['__typename'];
  }

  Map<String, dynamic> toJson() {
    final Map<String, dynamic> data = new Map<String, dynamic>();
    data['_id'] = this.sId;
    data['isMultiple'] = this.isMultiple;
    if (this.categoryIds != null) {
      data['categoryIds'] = this.categoryIds!.map((v) => v.toJson()).toList();
    }
    data['imageId'] = this.imageId;
    data['productId'] = this.productId;
    data['name'] = this.name;
    data['description'] = this.description;
    data['skuId'] = this.skuId;
    data['details'] = this.details;
    data['packVariant'] = this.packVariant;
    data['moq'] = this.moq;
    data['isOutofstock'] = this.isOutofstock;
    data['type'] = this.type;
    if (this.skuIds != null) {
      data['skuIds'] = this.skuIds!.map((v) => v.toJson()).toList();
    }
    if (this.children != null) {
      data['children'] = this.children!.map((v) => v.toJson()).toList();
    }
    if (this.price != null) {
      data['price'] = this.price!.toJson();
    }
    if (this.variantTypes != null) {
      data['variantTypes'] = this.variantTypes!.map((v) => v.toJson()).toList();
    }
    if (this.images != null) {
      data['images'] = this.images!.map((v) => v.toJson()).toList();
    }
    if (this.mergeAttribute != null) {
      data['mergeAttribute'] =
          this.mergeAttribute!.map((v) => v.toJson()).toList();
    }
    data['filterAttribute'] = this.filterAttribute;
    data['__typename'] = this.sTypename;
    return data;
  }
}

class CategoryIds {
  late final String? categoryName;
  late final String? link;
  late final int? level;
  late final String? sTypename;

  CategoryIds(
      {required this.categoryName,
      required this.link,
      required this.level,
      required this.sTypename});

  CategoryIds.fromJson(Map<String, dynamic> json) {
    categoryName = json['categoryName'];
    link = json['link'];
    level = json['level'];
    sTypename = json['__typename'];
  }

  Map<String, dynamic> toJson() {
    final Map<String, dynamic> data = new Map<String, dynamic>();
    data['categoryName'] = this.categoryName;
    data['link'] = this.link;
    data['level'] = this.level;
    data['__typename'] = this.sTypename;
    return data;
  }
}

class PriceDetails {
  late final double? sellingPrice;
  late final double? minPrice;
  late final double? maxPrice;
  late final double? mrp;
  late final String? type;
  late final double? discount;
  late final List<PriceRange>? priceRange;
  late final dynamic? priceRangeAll;
  late final String? sTypename;

  PriceDetails(
      {required this.sellingPrice,
      required this.minPrice,
      required this.maxPrice,
      required this.mrp,
      required this.type,
      required this.discount,
      required this.priceRange,
      required this.priceRangeAll,
      required this.sTypename});

  PriceDetails.fromJson(Map<String, dynamic> json) {
    sellingPrice = json['sellingPrice'].toDouble();
    minPrice = json['minPrice'].toDouble();
    maxPrice = json['maxPrice'].toDouble();
    mrp = json['mrp'].toDouble();
    type = json['type'];
    discount = json['discount'].toDouble();
    if (json['priceRange'] != null) {
      priceRange = <PriceRange>[];
      json['priceRange'].forEach((v) {
        priceRange!.add(new PriceRange.fromJson(v));
      });
    }
    priceRangeAll = json['priceRangeAll'];
    sTypename = json['__typename'];
  }

  Map<String, dynamic> toJson() {
    final Map<String, dynamic> data = new Map<String, dynamic>();
    data['sellingPrice'] = this.sellingPrice;
    data['minPrice'] = this.minPrice;
    data['maxPrice'] = this.maxPrice;
    data['mrp'] = this.mrp;
    data['type'] = this.type;
    data['discount'] = this.discount;
    if (this.priceRange != null) {
      data['priceRange'] = this.priceRange!.map((v) => v.toJson()).toList();
    }
    data['priceRangeAll'] = this.priceRangeAll;
    data['__typename'] = this.sTypename;
    return data;
  }
}

class PriceRange {
  late final String? id;
  late final int? minQty;
  late final int? maxQty;
  late final double? discount;
  late final double? sellingPrice;
  late final String? sTypename;

  PriceRange(
      {required this.id,
      required this.minQty,
      required this.maxQty,
      required this.discount,
      required this.sellingPrice,
      required this.sTypename});

  PriceRange.fromJson(Map<String, dynamic> json) {
    id = json['id'];
    minQty = json['minQty'];
    maxQty = json['maxQty'];
    discount = json['discount'].toDouble();
    sellingPrice = json['sellingPrice'].toDouble();
    sTypename = json['__typename'];
  }

  Map<String, dynamic> toJson() {
    final Map<String, dynamic> data = new Map<String, dynamic>();
    data['id'] = this.id;
    data['minQty'] = this.minQty;
    data['maxQty'] = this.maxQty;
    data['discount'] = this.discount;
    data['sellingPrice'] = this.sellingPrice;
    data['__typename'] = this.sTypename;
    return data;
  }
}

class VariantTypes {
  late final String? type;
  late final String? attributeFieldId;
  late final List<FieldValue>? fieldValue;
  late final String? sTypename;

  VariantTypes(
      {required this.type,
      required this.attributeFieldId,
      required this.fieldValue,
      required this.sTypename});

  VariantTypes.fromJson(Map<String, dynamic> json) {
    // print(json);
    type = json['type'];
    attributeFieldId = json['attributeFieldId'];
    if (json['fieldValue'] != null) {
      fieldValue = <FieldValue>[];
      json['fieldValue'].forEach((v) {
        fieldValue!.add(new FieldValue.fromJson(v));
      });
    }
    sTypename = json['__typename'];
  }

  Map<String, dynamic> toJson() {
    final Map<String, dynamic> data = new Map<String, dynamic>();
    data['type'] = this.type;
    data['attributeFieldId'] = this.attributeFieldId;
    if (this.fieldValue != null) {
      data['fieldValue'] = this.fieldValue!.map((v) => v.toJson()).toList();
    }
    data['__typename'] = this.sTypename;
    return data;
  }
}

class FieldValue {
  late final String? id;
  late final String? attributeFieldValueId;
  late final String? attributeFieldId;
  late final String? labelName;
  late final String? colorCode;
  late final bool? enable;
  late final dynamic? disabled;
  late final String? sTypename;

  FieldValue(
      {required this.id,
      required this.attributeFieldValueId,
      required this.attributeFieldId,
      required this.labelName,
      required this.colorCode,
      required this.enable,
      required this.disabled,
      required this.sTypename});

  FieldValue.fromJson(Map<String, dynamic> json) {
    id = json['id'];
    attributeFieldValueId = json['attributeFieldValueId'];
    attributeFieldId = json['attributeFieldId'];
    labelName = json['labelName'];
    colorCode = json['colorCode'];
    enable = json['enable'];
    disabled = json['disabled'];
    sTypename = json['__typename'];
  }

  Map<String, dynamic> toJson() {
    final Map<String, dynamic> data = new Map<String, dynamic>();
    data['id'] = this.id;
    data['attributeFieldValueId'] = this.attributeFieldValueId;
    data['attributeFieldId'] = this.attributeFieldId;
    data['labelName'] = this.labelName;
    data['colorCode'] = this.colorCode;
    data['enable'] = this.enable;
    data['disabled'] = this.disabled;
    data['__typename'] = this.sTypename;
    return data;
  }
}

class ImageDetails {
  late final String? imageName;
  late final int? position;
  late final String? sTypename;

  ImageDetails(
      {required this.imageName,
      required this.position,
      required this.sTypename});

  ImageDetails.fromJson(Map<String, dynamic> json) {
    imageName = json['imageName'];
    position = json['position'];
    sTypename = json['__typename'];
  }

  Map<String, dynamic> toJson() {
    final Map<String, dynamic> data = new Map<String, dynamic>();
    data['imageName'] = this.imageName;
    data['position'] = this.position;
    data['__typename'] = this.sTypename;
    return data;
  }
}

class MergeAttribute {
  late final String? type;
  late final String? attributeFieldId;
  late final String? fieldValue;
  late final String? sTypename;

  MergeAttribute(
      {required this.type,
      required this.attributeFieldId,
      required this.fieldValue,
      required this.sTypename});

  MergeAttribute.fromJson(Map<String, dynamic> json) {
    type = json['type'];
    attributeFieldId = json['attributeFieldId'];
    fieldValue = json['fieldValue'];
    sTypename = json['__typename'];
  }

  Map<String, dynamic> toJson() {
    final Map<String, dynamic> data = new Map<String, dynamic>();
    data['type'] = this.type;
    data['attributeFieldId'] = this.attributeFieldId;
    data['fieldValue'] = this.fieldValue;
    data['__typename'] = this.sTypename;
    return data;
  }
}
