import 'package:b2b_graphql_package/GraphQLConfiguration.dart';
import 'package:graphql_flutter/graphql_flutter.dart';

import 'homeSetting_model.dart';

class HomeRepo {
  var graphQLConfiguration;
  List<HomeSettingModel> homeSettingList = [];
  var retrieveLandingPageSettings;
  HomeRepo() {
    graphQLConfiguration = GraphQLConfiguration();
  }

  Future<List<HomeSettingModel>> getHomeSettings() async {
    var homeSettings;

    GraphQLClient _client = graphQLConfiguration.clientToQuery();

    var homeSettingGql = """ 
               {
            getAllEnableHomepageSetting {
            sortOrder
            type
            typeId
            display
            status
          _id
          }
          }
            """;

    QueryResult result = await _client.query(QueryOptions(
      document: gql(homeSettingGql),
      fetchPolicy: FetchPolicy.networkOnly,
    ));

    if (!result.hasException) {
      var settingsAvailable = result.data!['getAllEnableHomepageSetting'];

      if (settingsAvailable != null && settingsAvailable.length > 0) {
        settingsAvailable.forEach((element) => {
              homeSettings = new HomeSettingModel(
                element['_id'],
                element['sortOrder'],
                element['type'],
                element['typeId'],
                element['display'],
                element['status'],
              ),
              homeSettingList.add(homeSettings)
            });
      }
      return homeSettingList;
    }
    return homeSettingList;
  }

  Future retrieveLandingPage(String deviceType) async {
    GraphQLClient _client = graphQLConfiguration.clientToQuery();

    var retrieveLandingPageGql = """ 
                  query retrieveLandingPage(\$deviceType: String) {
                retrieveLandingPage(deviceType: \$deviceType) {
                  _id
                  title
                  contents {
                    _id
                    position
                    homeContentId {
                      _id
                      name
                      status
                      contentType
                      displayType
                      count
                      banners {
                        _id
                        title
                        imageName
                        status
                        link
                        __typename
                      }
                      promotions {
                        _id
                        packId
                        pack {
                          _id
                          packSKU
                          packName
                          packImages {
                            packImageName
                            __typename
                          }
                          setIds {
                            setPrice
                            __typename
                          }
                          __typename
                        }
                        __typename
                      }
                      __typename
                    }
                    __typename
                  }
                  __typename
                }
              }

            """;

    final vble = {
      "deviceType": deviceType,
    };
    QueryResult result = await _client.query(QueryOptions(
      document: gql(retrieveLandingPageGql),
      variables: vble,
      fetchPolicy: FetchPolicy.networkOnly,
    ));
    print(result.hasException);
    print(result.exception);
    if (!result.hasException) {
      var categoryPack = result.data!['retrieveLandingPage'];

      if (categoryPack != null && categoryPack.length > 0) {
        retrieveLandingPageSettings = retrieveLandingPageJson(categoryPack);
      }
      return retrieveLandingPageSettings;
    }
    return retrieveLandingPageSettings;
  }
}
