import '../cart/cart_model.dart';
import 'order_create_model.dart';

SingleOrder singleOrderFromJson(dynamic str) => (SingleOrder.fromJson(str));

class SingleOrder {
  late final String sId;
  late final String orderDate;
  late final String orderId;
  late final String? bookingId;
  late final String? cancellationReason;
  late final String? cancellationDate;
  late final String? returnReason;
  late final String? returnRequestedDate;
  late final String? returnRejectionReason;
  late final double shippingFees;
  late final int? paymentStatus;
  late final BillingAddress? billingAddress;
  late final ShippingAddress? shippingAddress;
  late final User? user;
  late final double? subTotal;
  late final double? totalGst;
  late final double? totalAmount;
  late final int? orderStatus;
  late final List<OrderItem>? orderItem;
  late final String? sTypename;

  SingleOrder(
      {required this.sId,
      required this.orderDate,
      required this.orderId,
      required this.bookingId,
      required this.cancellationReason,
      required this.cancellationDate,
      required this.returnReason,
      required this.returnRequestedDate,
      required this.returnRejectionReason,
      required this.shippingFees,
      required this.paymentStatus,
      required this.billingAddress,
      required this.shippingAddress,
      required this.user,
      required this.subTotal,
      required this.totalGst,
      required this.totalAmount,
      required this.orderStatus,
      required this.orderItem,
      required this.sTypename});

  SingleOrder.fromJson(Map<String, dynamic> json) {
    sId = json['_id'];
    orderDate = json['orderDate'];
    orderId = json['orderId'];
    bookingId = json['bookingId'];
    cancellationReason = json['cancellationReason'];
    cancellationDate = json['cancellationDate'];
    returnReason = json['returnReason'];
    returnRequestedDate = json['returnRequestedDate'];
    returnRejectionReason = json['returnRejectionReason'];
    shippingFees = json['shippingFees'] == 0
        ? json['shippingFees'].toDouble()
        : json['shippingFees'];
    paymentStatus = json['paymentStatus'];
    billingAddress = json['billingAddress'] != null
        ? new BillingAddress.fromJson(json['billingAddress'])
        : null;
    shippingAddress = json['shippingAddress'] != null
        ? new ShippingAddress.fromJson(json['shippingAddress'])
        : null;
    user = json['user'] != null ? new User.fromJson(json['user']) : null;
    subTotal = double.parse(json['subTotal'].toString());
    totalGst = json['totalGst'];
    totalAmount = json['totalAmount'];
    orderStatus = json['orderStatus'];
    if (json['orderItem'] != null) {
      orderItem = [];
      json['orderItem'].forEach((v) {
        orderItem!.add(new OrderItem.fromJson(v));
      });
    }
    sTypename = json['__typename'];
  }

  Map<String, dynamic> toJson() {
    final Map<String, dynamic> data = new Map<String, dynamic>();
    data['_id'] = this.sId;
    data['orderDate'] = this.orderDate;
    data['orderId'] = this.orderId;
    data['bookingId'] = this.bookingId;
    data['cancellationReason'] = this.cancellationReason;
    data['cancellationDate'] = this.cancellationDate;
    data['returnReason'] = this.returnReason;
    data['returnRequestedDate'] = this.returnRequestedDate;
    data['returnRejectionReason'] = this.returnRejectionReason;

    data['shippingFees'] = this.shippingFees;
    data['paymentStatus'] = this.paymentStatus;
    if (this.billingAddress != null) {
      data['billingAddress'] = this.billingAddress!.toJson();
    }
    if (this.shippingAddress != null) {
      data['shippingAddress'] = this.shippingAddress!.toJson();
    }
    if (this.user != null) {
      data['user'] = this.user!.toJson();
    }
    data['subTotal'] = this.subTotal;
    data['totalGst'] = this.totalGst;
    data['totalAmount'] = this.totalAmount;
    data['orderStatus'] = this.orderStatus;
    if (this.orderItem != null) {
      data['orderItem'] = this.orderItem!.map((v) => v.toJson()).toList();
    }
    data['__typename'] = this.sTypename;
    return data;
  }
}

class BillingAddress {
  late final String? contactName;
  late final String? companyName;
  late final String? emailId;
  late final int? mobileNumber;
  late final String? address;
  late final String? city;
  late final String? state;
  late final int? pincode;
  // late final String sTypename;

  BillingAddress({
    required this.contactName,
    required this.companyName,
    required this.emailId,
    required this.mobileNumber,
    required this.address,
    required this.city,
    required this.state,
    required this.pincode,
    // required this.sTypename
  });

  BillingAddress.fromJson(Map<String, dynamic> json) {
    contactName = json['contactName'];
    companyName = json['companyName'];
    emailId = json['emailId'];
    mobileNumber = json['mobileNumber'];
    address = json['address'];
    city = json['city'];
    state = json['state'];
    pincode = json['pincode'];
    // sTypename = json['__typename'];
  }

  Map<String, dynamic> toJson() {
    final Map<String, dynamic> data = new Map<String, dynamic>();
    data['contactName'] = this.contactName;
    data['companyName'] = this.companyName;
    data['emailId'] = this.emailId;
    data['mobileNumber'] = this.mobileNumber;
    data['address'] = this.address;
    data['city'] = this.city;
    data['state'] = this.state;
    data['pincode'] = this.pincode;
    // data['__typename'] = this.sTypename;
    return data;
  }
}

class ShippingAddress {
  late final String? contactName;
  late final String? companyName;
  late final String? emailId;
  late final int? mobileNumber;
  late final String? address;
  late final String? city;
  late final String? state;
  late final int? pincode;
  // late final String? sTypename;

  ShippingAddress({
    required this.contactName,
    required this.companyName,
    required this.emailId,
    required this.mobileNumber,
    required this.address,
    required this.city,
    required this.state,
    required this.pincode,
    // required this.sTypename
  });

  ShippingAddress.fromJson(Map<String, dynamic> json) {
    contactName = json['contactName'];
    companyName = json['companyName'];
    emailId = json['emailId'];
    mobileNumber = json['mobileNumber'];
    address = json['address'];
    city = json['city'];
    state = json['state'];
    pincode = json['pincode'];
    // sTypename = json['__typename'];
  }

  Map<String, dynamic> toJson() {
    final Map<String, dynamic> data = new Map<String, dynamic>();
    data['contactName'] = this.contactName;
    data['companyName'] = this.companyName;
    data['emailId'] = this.emailId;
    data['mobileNumber'] = this.mobileNumber;
    data['address'] = this.address;
    data['city'] = this.city;
    data['state'] = this.state;
    data['pincode'] = this.pincode;
    // data['__typename'] = this.sTypename;
    return data;
  }
}

class User {
  late final String? companyName;
  late final String? contactName;
  late final int? mobileNumber;
  late final String? emailId;
  late final String userId;
  late final String? gstNumber;

  User(
      {required this.companyName,
      required this.contactName,
      required this.mobileNumber,
      required this.emailId,
      required this.userId,
      required this.gstNumber});

  User.fromJson(Map<String, dynamic> json) {
    companyName = json['companyName'];
    contactName = json['contactName'];
    mobileNumber = json['mobileNumber'];
    emailId = json['emailId'];
    userId = json['userId'];
    gstNumber = json['gstNumber'];
  }

  Map<String, dynamic> toJson() {
    final Map<String, dynamic> data = new Map<String, dynamic>();
    data['contactName'] = this.contactName;
    data['mobileNumber'] = this.mobileNumber;
    data['emailId'] = this.emailId;
    data['userId'] = this.userId;
    // data['__typename'] = this.sTypename;
    return data;
  }
}

class OrderItem {
  late final int quantity;
  late final String? comments;
  late final String? variant;
  late final String? variantValue;
  late final double? price;
  late final int? piece;
  late final double? igst;
  late final double? cgst;
  late final double? sgst;
  late final Pack? pack;
  late final Set? sets;
  // late final String? sTypename;

  OrderItem({
    required this.quantity,
    required this.comments,
    required this.variant,
    required this.variantValue,
    required this.price,
    required this.piece,
    required this.igst,
    required this.cgst,
    required this.sgst,
    required this.pack,
    required this.sets,
    // required this.sTypename
  });

  OrderItem.fromJson(Map<String, dynamic> json) {
    quantity = json['quantity'];
    comments = json['comments'];
    variant = json['variant'];
    variantValue = json['variantValue'];
    price = json['price'].toDouble();
    piece = json['piece'];
    igst = json['igst'].toDouble();
    cgst = json['cgst'].toDouble();
    sgst = json['sgst'].toDouble();
    pack = json['pack'] != null ? new Pack.fromJson(json['pack']) : null;
    sets = json['set'] != null ? new Set.fromJson(json['set']) : null;
    // sTypename = json['__typename'];
  }

  Map<String, dynamic> toJson() {
    final Map<String, dynamic> data = new Map<String, dynamic>();
    data['quantity'] = this.quantity;
    data['comments'] = this.comments;
    data['variant'] = this.variant;
    data['variantValue'] = this.variantValue;
    data['price'] = this.price;
    data['piece'] = this.piece;
    data['igst'] = this.igst;
    data['cgst'] = this.cgst;
    data['sgst'] = this.sgst;
    if (this.pack != null) {
      data['pack'] = this.pack!.toJson();
    }
    if (this.sets != null) {
      data['set'] = this.sets!.toJson();
    }
    // data['__typename'] = this.sTypename;
    return data;
  }
}

GetOrderById getOrderByIdFromJson(dynamic str) => (GetOrderById.fromJson(str));

class GetOrderById {
  late final String? sId;
  late final String? orderDate;
  late final String? orderId;
  late final String? bookingId;
  late final double? shippingFees;
  late final String? returnReason;
  late final String? returnRejectionReason;
  late final String? cancellationReason;
  late final String? paymentMode;
  late final bool? checkPackage;
  late final String? imageUrl;
  late final int? paymentStatus;
  late final int? orderStatus;
  late final int? orderType;
  late final List<History>? history;
  late final User? user;
  late final Price? price;
  late final BillingAddress? billingAddress;
  late final BillingAddress? shippingAddress;
  late final List<OrderProducts>? orderProducts;
  late final String? sTypename;

  GetOrderById(
      {required this.sId,
      required this.orderDate,
      required this.orderId,
      required this.bookingId,
      required this.shippingFees,
      required this.returnReason,
      required this.returnRejectionReason,
      required this.cancellationReason,
      required this.paymentMode,
      required this.checkPackage,
      required this.imageUrl,
      required this.paymentStatus,
      required this.orderStatus,
      required this.orderType,
      required this.history,
      required this.user,
      required this.price,
      required this.billingAddress,
      required this.shippingAddress,
      required this.orderProducts,
      required this.sTypename});

  GetOrderById.fromJson(Map<String, dynamic> json) {
    sId = json['_id'];
    orderDate = json['orderDate'];
    orderId = json['orderId'];
    bookingId = json['bookingId'];
    shippingFees = json['shippingFees'];
    returnReason = json['returnReason'];
    returnRejectionReason = json['returnRejectionReason'];
    cancellationReason = json['cancellationReason'];
    paymentMode = json['paymentMode'];
    checkPackage = json['checkPackage'];
    imageUrl = json['imageUrl'];
    paymentStatus = json['paymentStatus'];
    orderStatus = json['orderStatus'];
    orderType = json['orderType'] ?? 1;
    if (json['history'] != null) {
      history = <History>[];
      json['history'].forEach((v) {
        history!.add(new History.fromJson(v));
      });
    }
    user = json['user'] != null ? new User.fromJson(json['user']) : null;
    price = json['price'] != null ? new Price.fromJson(json['price']) : null;
    billingAddress = json['billingAddress'] != null
        ? new BillingAddress.fromJson(json['billingAddress'])
        : null;
    shippingAddress = json['shippingAddress'] != null
        ? new BillingAddress.fromJson(json['shippingAddress'])
        : null;
    if (json['orderProducts'] != null) {
      orderProducts = <OrderProducts>[];
      json['orderProducts'].forEach((v) {
        orderProducts!.add(new OrderProducts.fromJson(v));
      });
    }
    sTypename = json['__typename'];
  }

  Map<String, dynamic> toJson() {
    final Map<String, dynamic> data = new Map<String, dynamic>();
    data['_id'] = this.sId;
    data['orderDate'] = this.orderDate;
    data['orderId'] = this.orderId;
    data['bookingId'] = this.bookingId;
    data['shippingFees'] = this.shippingFees;
    data['returnReason'] = this.returnReason;
    data['returnRejectionReason'] = this.returnRejectionReason;
    data['cancellationReason'] = this.cancellationReason;
    data['paymentMode'] = this.paymentMode;
    data['checkPackage'] = this.checkPackage;
    data['imageUrl'] = this.imageUrl;
    data['paymentStatus'] = this.paymentStatus;
    data['orderStatus'] = this.orderStatus;
    data['orderType'] = this.orderType;
    if (this.history != null) {
      data['history'] = this.history!.map((v) => v.toJson()).toList();
    }
    if (this.user != null) {
      data['user'] = this.user!.toJson();
    }
    if (this.price != null) {
      data['price'] = this.price!.toJson();
    }
    if (this.billingAddress != null) {
      data['billingAddress'] = this.billingAddress!.toJson();
    }
    if (this.shippingAddress != null) {
      data['shippingAddress'] = this.shippingAddress!.toJson();
    }
    if (this.orderProducts != null) {
      data['orderProducts'] =
          this.orderProducts!.map((v) => v.toJson()).toList();
    }
    data['__typename'] = this.sTypename;
    return data;
  }
}

class History {
  late final int? action;
  late final int? type;
  late final bool? customerView;
  late final String? date;
  late final String? sTypename;

  History(
      {required this.action,
      required this.type,
      required this.customerView,
      required this.date,
      required this.sTypename});

  History.fromJson(Map<String, dynamic> json) {
    action = json['action'];
    type = json['type'];
    customerView = json['customerView'];
    date = json['date'];
    sTypename = json['__typename'];
  }

  Map<String, dynamic> toJson() {
    final Map<String, dynamic> data = new Map<String, dynamic>();
    data['action'] = this.action;
    data['type'] = this.type;
    data['customerView'] = this.customerView;
    data['date'] = this.date;
    data['__typename'] = this.sTypename;
    return data;
  }
}

class Price {
  late final double? totalPrice;
  late final double? totalGstPrice;
  late final double? totalWithOutGstPrice;
  late final double? totalWithOutSCGstPrice;
  late final double? totalMrp;
  late final double? shippingPrice;
  late final double? shippingGstPrice;
  late final double? shippingCgstPrice;
  late final double? shippingSgstPrice;
  late final String? sTypename;
  late final double? resellerPrice;

  Price(
      {required this.totalPrice,
      required this.totalGstPrice,
      required this.totalWithOutGstPrice,
      required this.totalWithOutSCGstPrice,
      required this.totalMrp,
      required this.shippingPrice,
      required this.shippingGstPrice,
      required this.shippingCgstPrice,
      required this.shippingSgstPrice,
      required this.sTypename,
      required this.resellerPrice});

  Price.fromJson(Map<String, dynamic> json) {
    totalPrice = json['totalPrice']?.toDouble();
    totalGstPrice = json['totalGstPrice']?.toDouble();
    totalWithOutGstPrice = json['totalWithOutGstPrice']?.toDouble();
    totalWithOutSCGstPrice = json['totalWithOutSCGstPrice']?.toDouble();
    totalMrp = json['totalMrp']?.toDouble();
    shippingPrice = json['shippingPrice']?.toDouble();
    shippingGstPrice = json['shippingGstPrice']?.toDouble();
    shippingCgstPrice = json['shippingCgstPrice']?.toDouble();
    shippingSgstPrice = json['shippingSgstPrice']?.toDouble();
    resellerPrice = json['resellerPrice']?.toDouble() ?? 0.0;
    sTypename = json['__typename'];
  }

  Map<String, dynamic> toJson() {
    final Map<String, dynamic> data = new Map<String, dynamic>();
    data['totalPrice'] = this.totalPrice;
    data['totalGstPrice'] = this.totalGstPrice;
    data['totalWithOutGstPrice'] = this.totalWithOutGstPrice;
    data['totalWithOutSCGstPrice'] = this.totalWithOutSCGstPrice;
    data['totalMrp'] = this.totalMrp;
    data['shippingPrice'] = this.shippingPrice;
    data['shippingGstPrice'] = this.shippingGstPrice;
    data['shippingCgstPrice'] = this.shippingCgstPrice;
    data['shippingSgstPrice'] = this.shippingSgstPrice;
    data['resellerPrice'] = this.resellerPrice;
    data['__typename'] = this.sTypename;
    return data;
  }
}

class OrderProducts {
  late final String? sId;
  late final String? productName;
  late final String? imageId;
  late final String? productId;
  late final String? skuId;
  late final String? productDescription;
  late final String? type;
  late final bool? isMultiple;
  late final List<Category>? category;
  late final List<Brand>? brand;
  late final List<Attribute>? attribute;
  late final OrderPrice? price;
  late final int? totalPieces;
  late final int? qty;
  late final String? imageUrl;
  late final List<SkuIds>? skuIds;
  late final List<Null>? children;
  late final String? sTypename;

  OrderProducts(
      {required this.sId,
      required this.productName,
      required this.imageId,
      required this.productId,
      required this.skuId,
      required this.productDescription,
      required this.type,
      required this.isMultiple,
      required this.category,
      required this.brand,
      required this.attribute,
      required this.price,
      required this.totalPieces,
      required this.qty,
      required this.imageUrl,
      required this.skuIds,
      required this.children,
      required this.sTypename});

  OrderProducts.fromJson(Map<String, dynamic> json) {
    sId = json['_id'];
    productName = json['productName'];
    imageId = json['imageId'];
    productId = json['productId'];
    skuId = json['skuId'];
    productDescription = json['productDescription'];
    type = json['type'];
    isMultiple = json['isMultiple'];
    if (json['category'] != null) {
      category = <Category>[];
      json['category'].forEach((v) {
        category!.add(new Category.fromJson(v));
      });
    }
    if (json['brand'] != null) {
      brand = <Brand>[];
      json['brand'].forEach((v) {
        brand!.add(new Brand.fromJson(v));
      });
    }
    if (json['attribute'] != null) {
      attribute = <Attribute>[];
      json['attribute'].forEach((v) {
        attribute!.add(new Attribute.fromJson(v));
      });
    }
    price =
        json['price'] != null ? new OrderPrice.fromJson(json['price']) : null;
    totalPieces = json['totalPieces'];
    qty = json['qty'];
    imageUrl = json['imageUrl'];
    if (json['skuIds'] != null) {
      skuIds = <SkuIds>[];
      json['skuIds'].forEach((v) {
        skuIds!.add(new SkuIds.fromJson(v));
      });
    }
    if (json['children'] != null) {
      children = <Null>[];
      json['children'].forEach((v) {
        children!.add(v);
      });
    }
    sTypename = json['__typename'];
  }

  Map<String, dynamic> toJson() {
    final Map<String, dynamic> data = new Map<String, dynamic>();
    data['_id'] = this.sId;
    data['productName'] = this.productName;
    data['imageId'] = this.imageId;
    data['productId'] = this.productId;
    data['skuId'] = this.skuId;
    data['productDescription'] = this.productDescription;
    data['type'] = this.type;
    data['isMultiple'] = this.isMultiple;
    if (this.category != null) {
      data['category'] = this.category!.map((v) => v.toJson()).toList();
    }
    if (this.brand != null) {
      data['brand'] = this.brand!.map((v) => v.toJson()).toList();
    }
    if (this.attribute != null) {
      data['attribute'] = this.attribute!.map((v) => v.toJson()).toList();
    }
    if (this.price != null) {
      data['price'] = this.price!.toJson();
    }
    data['totalPieces'] = this.totalPieces;
    data['qty'] = this.qty;
    data['imageUrl'] = this.imageUrl;
    if (this.skuIds != null) {
      data['skuIds'] = this.skuIds!.map((v) => v.toJson()).toList();
    }
    if (this.children != null) {
      data['children'] = this.children!.map((v) => v).toList();
    }
    data['__typename'] = this.sTypename;
    return data;
  }
}

class Category {
  late final String? sId;
  late final String? categoryName;
  late final String? sTypename;

  Category(
      {required this.sId, required this.categoryName, required this.sTypename});

  Category.fromJson(Map<String, dynamic> json) {
    sId = json['_id'];
    categoryName = json['categoryName'];
    sTypename = json['__typename'];
  }

  Map<String, dynamic> toJson() {
    final Map<String, dynamic> data = new Map<String, dynamic>();
    data['_id'] = this.sId;
    data['categoryName'] = this.categoryName;
    data['__typename'] = this.sTypename;
    return data;
  }
}

class Brand {
  late final String? sId;
  late final String? brandName;
  late final String? sTypename;

  Brand({required this.sId, required this.brandName, required this.sTypename});

  Brand.fromJson(Map<String, dynamic> json) {
    sId = json['_id'];
    brandName = json['brandName'];
    sTypename = json['__typename'];
  }

  Map<String, dynamic> toJson() {
    final Map<String, dynamic> data = new Map<String, dynamic>();
    data['_id'] = this.sId;
    data['brandName'] = this.brandName;
    data['__typename'] = this.sTypename;
    return data;
  }
}

class Attribute {
  late final String? fieldName;
  late final String? fieldValue;
  late final String? colorCode;
  late final String? sTypename;

  Attribute(
      {required this.fieldName,
      required this.fieldValue,
      required this.colorCode,
      required this.sTypename});

  Attribute.fromJson(Map<String, dynamic> json) {
    fieldName = json['fieldName'];
    fieldValue = json['fieldValue'];
    colorCode = json['colorCode'];
    sTypename = json['__typename'];
  }

  Map<String, dynamic> toJson() {
    final Map<String, dynamic> data = new Map<String, dynamic>();
    data['fieldName'] = this.fieldName;
    data['fieldValue'] = this.fieldValue;
    data['colorCode'] = this.colorCode;
    data['__typename'] = this.sTypename;
    return data;
  }
}

class OrderPrice {
  late final double? mrp;
  late final double? sellingPrice;
  late final double? discount;
  late final double? totalPrice;
  late final double? gstLabelName;
  late final double? withOutGstPrice;
  late final double? sgstLabelName;
  late final double? cgstLabelName;
  late final double? totalSgst;
  late final double? totalCgst;
  late final double? withOutSCGstPrice;
  late final double? totalGst;
  late final String? sTypename;

  OrderPrice(
      {required this.mrp,
      required this.sellingPrice,
      required this.discount,
      required this.totalPrice,
      required this.gstLabelName,
      required this.withOutGstPrice,
      required this.sgstLabelName,
      required this.cgstLabelName,
      required this.totalSgst,
      required this.totalCgst,
      required this.withOutSCGstPrice,
      required this.totalGst,
      required this.sTypename});

  OrderPrice.fromJson(Map<String, dynamic> json) {
    mrp = json['mrp'].toDouble();
    sellingPrice = json['sellingPrice'].toDouble();
    discount = json['discount'].toDouble();
    totalPrice = json['totalPrice'].toDouble();
    gstLabelName = json['gstLabelName'].toDouble();
    withOutGstPrice = json['withOutGstPrice'].toDouble();
    sgstLabelName = json['sgstLabelName'].toDouble();
    cgstLabelName = json['cgstLabelName'].toDouble();
    totalSgst = json['totalSgst'].toDouble();
    totalCgst = json['totalCgst'].toDouble();
    withOutSCGstPrice = json['withOutSCGstPrice'].toDouble();
    totalGst = json['totalGst'].toDouble();
    sTypename = json['__typename'];
  }

  Map<String, dynamic> toJson() {
    final Map<String, dynamic> data = new Map<String, dynamic>();
    data['mrp'] = this.mrp;
    data['sellingPrice'] = this.sellingPrice;
    data['discount'] = this.discount;
    data['totalPrice'] = this.totalPrice;
    data['gstLabelName'] = this.gstLabelName;
    data['withOutGstPrice'] = this.withOutGstPrice;
    data['sgstLabelName'] = this.sgstLabelName;
    data['cgstLabelName'] = this.cgstLabelName;
    data['totalSgst'] = this.totalSgst;
    data['totalCgst'] = this.totalCgst;
    data['withOutSCGstPrice'] = this.withOutSCGstPrice;
    data['totalGst'] = this.totalGst;
    data['__typename'] = this.sTypename;
    return data;
  }
}

class SkuIds {
  late final String? sku;
  late final String? imageId;
  late final String? styleCode;
  late final String? skuId;
  late final List<Attribute>? attribute;
  late final List<Category>? category;
  late final Brand? brand;
  late final Null productDimension;
  late final Null packingDimension;
  late final Null weight;
  late final String? productId;
  late final String? type;
  late final bool? isMultiple;
  late final String? productName;
  late final String? imageUrl;
  late final String? productDescription;
  late final Price? price;
  late final int? qty;
  late final String? sTypename;

  SkuIds(
      {required this.sku,
      required this.imageId,
      required this.styleCode,
      required this.skuId,
      required this.attribute,
      required this.category,
      required this.brand,
      required this.productDimension,
      required this.packingDimension,
      required this.weight,
      required this.productId,
      required this.type,
      required this.isMultiple,
      required this.productName,
      required this.imageUrl,
      required this.productDescription,
      required this.price,
      required this.qty,
      required this.sTypename});

  SkuIds.fromJson(Map<String, dynamic> json) {
    sku = json['sku'];
    imageId = json['imageId'];
    styleCode = json['styleCode'];
    skuId = json['skuId'];
    if (json['attribute'] != null) {
      attribute = <Attribute>[];
      json['attribute'].forEach((v) {
        attribute!.add(new Attribute.fromJson(v));
      });
    }
    if (json['category'] != null) {
      category = <Category>[];
      json['category'].forEach((v) {
        category!.add(new Category.fromJson(v));
      });
    }
    brand = json['brand'] != null ? new Brand.fromJson(json['brand']) : null;
    productDimension = json['productDimension'];
    packingDimension = json['packingDimension'];
    weight = json['weight'];
    productId = json['productId'];
    type = json['type'];
    isMultiple = json['isMultiple'];
    productName = json['productName'];
    imageUrl = json['imageUrl'];
    productDescription = json['productDescription'];
    price = json['price'] != null ? new Price.fromJson(json['price']) : null;
    qty = json['qty'];
    sTypename = json['__typename'];
  }

  Map<String, dynamic> toJson() {
    final Map<String, dynamic> data = new Map<String, dynamic>();
    data['sku'] = this.sku;
    data['imageId'] = this.imageId;
    data['styleCode'] = this.styleCode;
    data['skuId'] = this.skuId;
    if (this.attribute != null) {
      data['attribute'] = this.attribute!.map((v) => v.toJson()).toList();
    }
    if (this.category != null) {
      data['category'] = this.category!.map((v) => v.toJson()).toList();
    }
    if (this.brand != null) {
      data['brand'] = this.brand!.toJson();
    }
    data['productDimension'] = this.productDimension;
    data['packingDimension'] = this.packingDimension;
    data['weight'] = this.weight;
    data['productId'] = this.productId;
    data['type'] = this.type;
    data['isMultiple'] = this.isMultiple;
    data['productName'] = this.productName;
    data['imageUrl'] = this.imageUrl;
    data['productDescription'] = this.productDescription;
    if (this.price != null) {
      data['price'] = this.price!.toJson();
    }
    data['qty'] = this.qty;
    data['__typename'] = this.sTypename;
    return data;
  }
}

Pack packFromJson(dynamic str) => (Pack.fromDynamicJson(str));

class Pack {
  late final List<String> categoryId;
  late final String? packSKU;
  late final String? packName;
  late final int? moq;
  late final String? packVariant;
  late final String? packImage;
  late final String? packId;
  // late final String? sTypename;

  Pack({
    required this.categoryId,
    required this.packSKU,
    required this.packName,
    required this.moq,
    required this.packVariant,
    required this.packImage,
    required this.packId,
    // required this.sTypename
  });

  Pack.fromJson(Map<String, dynamic> json) {
    categoryId = json['categoryId'].cast<String>();
    packSKU = json['packSKU'];
    packName = json['packName'];
    moq = json['moq'];
    packVariant = json['packVariant'];
    packImage = json['packImage'];
    packId = json['packId'];
    // sTypename = json['__typename'];
  }

  Pack.fromDynamicJson(dynamic json) {
    categoryId = json.categoryId.cast<String>();
    packSKU = json.packSKU;
    packName = json.packName;
    moq = json.moq;
    packVariant = json.packVariant;
    packImage = json.packImage;
    packId = json.packId;
    // sTypename = json.sTypename;
  }

  Map<String, dynamic> toJson() {
    final Map<String, dynamic> data = new Map<String, dynamic>();
    data['categoryId'] = this.categoryId;
    data['packSKU'] = this.packSKU;
    data['packName'] = this.packName;
    data['moq'] = this.moq;
    data['packVariant'] = this.packVariant;
    data['packImage'] = this.packImage;
    data['packId'] = this.packId;
    // data['__typename'] = this.sTypename;
    return data;
  }
}

Set setFromJson(dynamic str) => (Set.fromDynamicJson(str));

class Set {
  late final String? setCode;
  late final String? setId;
  late final List<Sku>? sku;
  // late final String? sTypename;

  Set({
    required this.setCode,
    required this.setId,
    required this.sku,
    // required this.sTypename
  });

  Set.fromJson(Map<String, dynamic> json) {
    setCode = json['setCode'];
    setId = json['setId'];
    if (json['sku'] != null) {
      sku = [];
      json['sku'].forEach((v) {
        sku!.add(new Sku.fromJson(v));
      });
    }
    // sTypename = json['__typename'];
  }

  Set.fromDynamicJson(dynamic json) {
    setCode = json.setCode;
    setId = json.setId;
    if (json.sku != null) {
      sku = [];
      json.sku.forEach((v) {
        sku!.add(new Sku.fromDynamicJson(v));
      });
    }
    // sTypename = json.sTypename;
  }

  Map<String, dynamic> toJson() {
    final Map<String, dynamic> data = new Map<String, dynamic>();
    data['setCode'] = this.setCode;
    data['setId'] = this.setId;
    if (this.sku != null) {
      data['sku'] = this.sku!.map((v) => v.toJson()).toList();
    }
    // data['__typename'] = this.sTypename;
    return data;
  }
}

Sku skuDynamicFromJson(dynamic str) => (Sku.fromDynamicJson(str));

class Sku {
  late final double? setSkuPrice;
  late final int? setQuantity;
  late final String? skuId;
  late final String? sku;
  late final String? styleCode;
  late final String? variationType;
  late final double? b2cSellingPrice;
  late final double? b2bSellingPrice;
  late final double? mrp;
  late final double? discount;
  late final String? productName;
  late final String? iNTsku;
  late final String? sizeAttributeSettingId;
  late final String? sizeAttributeSettingFieldValueId;
  late final String? colorAttributeSettingId;
  late final String? colorAttributeSettingFieldValueId;
  late final String? sizeAttributeName;
  late final String? colorAttributeName;
  late final String? sizeAttributeFieldValue;
  late final String? colorAttributeFieldValue;
  late final String? gstTypeId;
  late final double? gstValue;
  // late final String? sTypename;

  Sku({
    required this.setSkuPrice,
    required this.setQuantity,
    required this.skuId,
    required this.sku,
    required this.styleCode,
    required this.variationType,
    required this.b2cSellingPrice,
    required this.b2bSellingPrice,
    required this.mrp,
    required this.discount,
    required this.productName,
    required this.iNTsku,
    required this.sizeAttributeSettingId,
    required this.sizeAttributeSettingFieldValueId,
    required this.colorAttributeSettingId,
    required this.colorAttributeSettingFieldValueId,
    required this.sizeAttributeName,
    required this.colorAttributeName,
    required this.sizeAttributeFieldValue,
    required this.colorAttributeFieldValue,
    required this.gstTypeId,
    required this.gstValue,
    // required this.sTypename
  });

  Sku.fromJson(Map<String, dynamic> json) {
    setSkuPrice = json['setSkuPrice'].toDouble();
    setQuantity = json['setQuantity'];
    skuId = json['skuId'];
    sku = json['sku'];
    styleCode = json['styleCode'];
    variationType = json['variationType'];
    b2cSellingPrice = json['b2cSellingPrice'].toDouble();
    b2bSellingPrice = json['b2bSellingPrice'].toDouble();
    mrp = json['mrp'].toDouble();
    discount = json['discount'].toDouble();
    productName = json['productName'];
    iNTsku = json['INTsku'];
    sizeAttributeSettingId = json['sizeAttributeSettingId'];
    sizeAttributeSettingFieldValueId = json['sizeAttributeSettingFieldValueId'];
    colorAttributeSettingId = json['colorAttributeSettingId'];
    colorAttributeSettingFieldValueId =
        json['colorAttributeSettingFieldValueId'];
    sizeAttributeName = json['sizeAttributeName'];
    colorAttributeName = json['colorAttributeName'];
    sizeAttributeFieldValue = json['sizeAttributeFieldValue'];
    colorAttributeFieldValue = json['colorAttributeFieldValue'];
    gstTypeId = json['gstTypeId'];
    gstValue = json['gstValue'].toDouble();
    // sTypename = json['__typename'];
  }

  Sku.fromDynamicJson(dynamic json) {
    setSkuPrice = json.setSkuPrice.toDouble();
    setQuantity = json.setQuantity;
    skuId = json.skuId;
    sku = json.sku;
    styleCode = json.styleCode;
    variationType = json.variationType;
    b2cSellingPrice = json.b2cSellingPrice.toDouble();
    b2bSellingPrice = json.b2bSellingPrice.toDouble();
    mrp = json.mrp.toDouble();
    discount = json.discount.toDouble();
    productName = json.productName;
    iNTsku = json.iNTsku;
    sizeAttributeSettingId = json.sizeAttributeSettingId;
    sizeAttributeSettingFieldValueId = json.sizeAttributeSettingFieldValueId;
    colorAttributeSettingId = json.colorAttributeSettingId;
    colorAttributeSettingFieldValueId = json.colorAttributeSettingFieldValueId;
    sizeAttributeName = json.sizeAttributeName;
    colorAttributeName = json.colorAttributeName;
    sizeAttributeFieldValue = json.sizeAttributeFieldValue;
    colorAttributeFieldValue = json.colorAttributeFieldValue;
    gstTypeId = json.gstTypeId;
    gstValue = json.gstValue.toDouble();
    // sTypename = json.sTypename;
  }

  Map<String, dynamic> toJson() {
    final Map<String, dynamic> data = new Map<String, dynamic>();
    data['setSkuPrice'] = this.setSkuPrice;
    data['setQuantity'] = this.setQuantity;
    data['skuId'] = this.skuId;
    data['sku'] = this.sku;
    data['styleCode'] = this.styleCode;
    data['variationType'] = this.variationType;
    data['b2cSellingPrice'] = this.b2cSellingPrice;
    data['b2bSellingPrice'] = this.b2bSellingPrice;
    data['mrp'] = this.mrp;
    data['discount'] = this.discount;
    data['productName'] = this.productName;
    data['INTsku'] = this.iNTsku;
    data['sizeAttributeSettingId'] = this.sizeAttributeSettingId;
    data['sizeAttributeSettingFieldValueId'] =
        this.sizeAttributeSettingFieldValueId;
    data['colorAttributeSettingId'] = this.colorAttributeSettingId;
    data['colorAttributeSettingFieldValueId'] =
        this.colorAttributeSettingFieldValueId;
    data['sizeAttributeName'] = this.sizeAttributeName;
    data['colorAttributeName'] = this.colorAttributeName;
    data['sizeAttributeFieldValue'] = this.sizeAttributeFieldValue;
    data['colorAttributeFieldValue'] = this.colorAttributeFieldValue;
    data['gstTypeId'] = this.gstTypeId;
    data['gstValue'] = this.gstValue;
    // data['__typename'] = this.sTypename;
    return data;
  }
}

CheckOrderCancellation orderCancellationFromJson(dynamic str) =>
    (CheckOrderCancellation.fromJson(str));

class CheckOrderCancellation {
  late final bool enableCancellation;
  late final String? message;
  late final String? timePeriod;
  late final int? hours;
  late final String sTypename;

  CheckOrderCancellation(
      {required this.enableCancellation,
      required this.message,
      required this.timePeriod,
      required this.hours,
      required this.sTypename});

  CheckOrderCancellation.fromJson(Map<String, dynamic> json) {
    enableCancellation = json['enableCancellation'];
    message = json['message'];
    timePeriod = json['timePeriod'];
    hours = json['hours'];
    sTypename = json['__typename'];
  }

  Map<String, dynamic> toJson() {
    final Map<String, dynamic> data = new Map<String, dynamic>();
    data['enableCancellation'] = this.enableCancellation;
    data['message'] = this.message;
    data['timePeriod'] = this.timePeriod;
    data['hours'] = this.hours;
    data['__typename'] = this.sTypename;
    return data;
  }
}

OrderCancelContent orderCancelContentFromJson(dynamic str) =>
    (OrderCancelContent.fromJson(str));

class OrderCancelContent {
  late final List<Reasons>? reasons;
  late final List<Message>? message;
  late final String sTypename;

  OrderCancelContent(
      {required this.reasons, required this.message, required this.sTypename});

  OrderCancelContent.fromJson(Map<String, dynamic> json) {
    if (json['reasons'] != null) {
      reasons = [];
      json['reasons'].forEach((v) {
        reasons!.add(new Reasons.fromJson(v));
      });
    } else {
      reasons = null;
    }
    if (json['message'] != null) {
      message = [];
      json['message'].forEach((v) {
        message!.add(new Message.fromJson(v));
      });
    } else {
      message = null;
    }
    sTypename = json['__typename'];
  }

  Map<String, dynamic> toJson() {
    final Map<String, dynamic> data = new Map<String, dynamic>();
    if (this.reasons != null) {
      data['reasons'] = this.reasons!.map((v) => v.toJson()).toList();
    }
    if (this.message != null) {
      data['message'] = this.message!.map((v) => v.toJson()).toList();
    }
    data['__typename'] = this.sTypename;
    return data;
  }
}

class Reasons {
  late final String? content;
  late final String sTypename;

  Reasons({required this.content, required this.sTypename});

  Reasons.fromJson(Map<String, dynamic> json) {
    content = json['content'];
    sTypename = json['__typename'];
  }

  Map<String, dynamic> toJson() {
    final Map<String, dynamic> data = new Map<String, dynamic>();
    data['content'] = this.content;
    data['__typename'] = this.sTypename;
    return data;
  }
}

class Message {
  late final String? content;
  late final String sTypename;

  Message({required this.content, required this.sTypename});

  Message.fromJson(Map<String, dynamic> json) {
    content = json['content'];
    sTypename = json['__typename'];
  }

  Map<String, dynamic> toJson() {
    final Map<String, dynamic> data = new Map<String, dynamic>();
    data['content'] = this.content;
    data['__typename'] = this.sTypename;
    return data;
  }
}

CheckOrderRetunable orderRetunFromJson(dynamic str) =>
    (CheckOrderRetunable.fromJson(str));

class CheckOrderRetunable {
  late final bool enableReturn;
  late final String? message;
  late final String? timePeriod;
  late final int? hours;
  late final String sTypename;

  CheckOrderRetunable(
      {required this.enableReturn,
      required this.message,
      required this.timePeriod,
      required this.hours,
      required this.sTypename});

  CheckOrderRetunable.fromJson(Map<String, dynamic> json) {
    enableReturn = json['enableReturn'];
    message = json['message'];
    timePeriod = json['timePeriod'];
    hours = json['hours'];
    sTypename = json['__typename'];
  }

  Map<String, dynamic> toJson() {
    final Map<String, dynamic> data = new Map<String, dynamic>();
    data['enableReturn'] = this.enableReturn;
    data['message'] = this.message;
    data['timePeriod'] = this.timePeriod;
    data['hours'] = this.hours;
    data['__typename'] = this.sTypename;
    return data;
  }
}

CreateOrderRequest createOrderRequestFromJson(dynamic str) =>
    (CreateOrderRequest.fromJson(str));

class CreateOrderRequest {
  late final BillingAddress? billingAddress;
  late final ShippingAddress? shippingAddress;
  late final User? user;
  late final int? orderStatus;
  late final int? paymentStatus;
  late final PriceDetails? price;
  late final String? imageUrl;
  late final List<OrderProductDetails>? orderProducts;
  late final int? orderType;

  CreateOrderRequest(
      {required this.billingAddress,
      required this.shippingAddress,
      required this.user,
      required this.orderStatus,
      required this.paymentStatus,
      required this.price,
      required this.imageUrl,
      required this.orderProducts,
      required this.orderType});

  CreateOrderRequest.fromJson(Map<String, dynamic> json) {
    billingAddress = json['billingAddress'] != null
        ? new BillingAddress.fromJson(json['billingAddress'])
        : null;
    shippingAddress = json['shippingAddress'] != null
        ? new ShippingAddress.fromJson(json['shippingAddress'])
        : null;
    user = json['user'] != null ? new User.fromJson(json['user']) : null;
    orderStatus = json['orderStatus'];
    paymentStatus = json['paymentStatus'];
    orderType = json['orderType'];
    price =
        json['price'] != null ? new PriceDetails.fromJson(json['price']) : null;
    imageUrl = json['imageUrl'];
    if (json['orderItem'] != null) {
      orderProducts = [];
      json['orderItem'].forEach((v) {
        orderProducts!.add(new OrderProductDetails.fromJson(v));
      });
    }
  }

  Map<String, dynamic> toJson() {
    final Map<String, dynamic> data = new Map<String, dynamic>();
    if (this.billingAddress != null) {
      data['billingAddress'] = this.billingAddress!.toJson();
    }
    if (this.shippingAddress != null) {
      data['shippingAddress'] = this.shippingAddress!.toJson();
    }
    if (this.user != null) {
      data['user'] = this.user!.toJson();
    }
    data['orderStatus'] = this.orderStatus;
    data['paymentStatus'] = this.paymentStatus;
    data['orderType'] = this.orderType;
    if (this.price != null) {
      data['price'] = this.price!.toJson();
    }
    data['imageUrl'] = this.imageUrl;
    if (this.orderProducts != null) {
      data['orderProducts'] =
          this.orderProducts!.map((v) => v.toJson()).toList();
    }

    return data;
  }
}

class PriceDetails {
  late final double? subTotalPrice;
  late final double? totalGstPrice;
  late final double? totalWithOutGstPrice;
  late final double? totalMrp;
  late final double? shippingPrice;
  late final double? totalPrice;
  late final double? resellerPrice;

  PriceDetails(
      {required this.subTotalPrice,
      required this.totalGstPrice,
      required this.totalWithOutGstPrice,
      required this.totalMrp,
      required this.shippingPrice,
      required this.totalPrice,
      this.resellerPrice});

  PriceDetails.fromJson(Map<String, dynamic> json) {
    subTotalPrice = json['subTotalPrice']?.toDouble();
    totalGstPrice = json['totalGstPrice']?.toDouble();
    totalWithOutGstPrice = json['totalWithOutGstPrice']?.toDouble();
    totalMrp = json['totalMrp']?.toDouble();
    shippingPrice = json['shippingPrice']?.toDouble();
    totalPrice = json['totalPrice']?.toDouble();
    resellerPrice = json['resellerPrice']?.toDouble();
  }

  Map<String, dynamic> toJson() {
    final Map<String, dynamic> data = new Map<String, dynamic>();
    data['subTotalPrice'] = this.subTotalPrice;
    data['totalGstPrice'] = this.totalGstPrice;
    data['totalWithOutGstPrice'] = this.totalWithOutGstPrice;
    data['totalMrp'] = this.totalMrp;
    data['shippingPrice'] = this.shippingPrice;
    data['totalPrice'] = this.totalPrice;
    data['resellerPrice'] = this.resellerPrice;
    return data;
  }
}

CreateOrderResponse createOrderResponseFromJson(dynamic str) =>
    (CreateOrderResponse.fromJson(str));

class CreateOrderResponse {
  late final String sId;
  late final double? shippingFees;
  late final double? totalAmount;
  late final String? orderDate;
  late final String? orderId;
  late final String? bookingId;
  late final List<dynamic> history;
  late final int? paymentStatus;
  late final BillingAddress? billingAddress;
  late final BillingAddress? shippingAddress;
  late final User? user;
  late final double? subTotal;
  late final double? totalGst;
  late final int? orderStatus;
  late final List<OrderItem>? orderItem;
  late final PriceDetails? price;
  late final String sTypename;
  late final int? orderType;

  CreateOrderResponse(
      {required this.sId,
      required this.shippingFees,
      required this.totalAmount,
      required this.orderDate,
      required this.orderId,
      required this.bookingId,
      required this.history,
      required this.paymentStatus,
      required this.billingAddress,
      required this.shippingAddress,
      required this.user,
      required this.subTotal,
      required this.totalGst,
      required this.orderStatus,
      required this.orderItem,
      required this.price,
      required this.sTypename,
      required this.orderType});

  CreateOrderResponse.fromJson(Map<String, dynamic> json) {
    sId = json['_id'];
    shippingFees = json['shippingFees']?.toDouble();
    totalAmount = json['totalAmount']?.toDouble();
    orderDate = json['orderDate'];
    orderId = json['orderId'];
    orderType = json['orderType'];
    bookingId = json['bookingId'];
    if (json['history'] != null) {
      history = [];
      json['history'].forEach((v) {
        history.add(v);
      });
    }
    paymentStatus = json['paymentStatus'];
    billingAddress = json['billingAddress'] != null
        ? new BillingAddress.fromJson(json['billingAddress'])
        : null;
    shippingAddress = json['shippingAddress'] != null
        ? new BillingAddress.fromJson(json['shippingAddress'])
        : null;
    user = json['user'] != null ? new User.fromJson(json['user']) : null;
    subTotal = json['subTotal']?.toDouble();
    totalGst = json['totalGst']?.toDouble();
    orderStatus = json['orderStatus'];
    if (json['orderItem'] != null) {
      orderItem = [];
      json['orderItem'].forEach((v) {
        orderItem!.add(new OrderItem.fromJson(v));
      });
    }
    price =
        json['price'] != null ? new PriceDetails.fromJson(json['price']) : null;
    sTypename = json['__typename'];
  }

  Map<String, dynamic> toJson() {
    final Map<String, dynamic> data = new Map<String, dynamic>();
    data['_id'] = this.sId;
    data['shippingFees'] = this.shippingFees;
    data['totalAmount'] = this.totalAmount;
    data['orderDate'] = this.orderDate;
    data['orderId'] = this.orderId;
    data['bookingId'] = this.bookingId;
    data['orderType'] = this.orderType;
    if (this.history != null) {
      data['history'] = this.history.map((v) => v.toJson()).toList();
    }
    data['paymentStatus'] = this.paymentStatus;
    if (this.billingAddress != null) {
      data['billingAddress'] = this.billingAddress!.toJson();
    }
    if (this.shippingAddress != null) {
      data['shippingAddress'] = this.shippingAddress!.toJson();
    }
    if (this.user != null) {
      data['user'] = this.user!.toJson();
    }
    data['subTotal'] = this.subTotal;
    data['totalGst'] = this.totalGst;
    data['orderStatus'] = this.orderStatus;
    if (this.orderItem != null) {
      data['orderItem'] = this.orderItem!.map((v) => v.toJson()).toList();
    }
    if (this.price != null) {
      data['price'] = this.price!.toJson();
    }
    data['__typename'] = this.sTypename;
    return data;
  }
}
