SinglePack singlePackFromJson(dynamic str) => (SinglePack.fromJson(str));

class SinglePack {
  late final String sId;
  late final String packName;
  late final String packDescription;
  late final int moq;
  late final String packVariant;
  late final List<dynamic> packColorLabel;
  late final HeadSetInformation? headSetInformation;
  late final List<PackImages> packImages;
  late final List<PackOptions> packOptions;
  List<String>? categoryId;
  late final String sTypename;

  SinglePack(
      {required this.sId,
      required this.packName,
      required this.packDescription,
      required this.moq,
      required this.packVariant,
      required this.packColorLabel,
      required this.headSetInformation,
      required this.packImages,
      required this.packOptions,
      required this.categoryId,
      required this.sTypename});

  SinglePack.fromJson(Map<String, dynamic> json) {
    sId = json['_id'];
    packName = json['packName'];
    packDescription = json['packDescription'];
    moq = json['moq'];
    packVariant = json['packVariant'];
    if (json['packColorLabel'] != null) {
      packColorLabel = [];
      json['packColorLabel'].forEach((v) {
        packColorLabel.add((v));
      });
    }
    headSetInformation = json['headSetInformation'] != null
        ? new HeadSetInformation.fromJson(json['headSetInformation'])
        : null;
    if (json['packImages'] != null) {
      packImages = [];
      json['packImages'].forEach((v) {
        packImages.add(new PackImages.fromJson(v));
      });
    }
    if (json['packOptions'] != null) {
      packOptions = [];
      json['packOptions'].forEach((v) {
        packOptions.add(new PackOptions.fromJson(v));
      });
    }
    categoryId = json['categoryId'].cast<String>();
    sTypename = json['__typename'];
  }

  Map<String, dynamic> toJson() {
    final Map<String, dynamic> data = new Map<String, dynamic>();
    data['_id'] = this.sId;
    data['packName'] = this.packName;
    data['packDescription'] = this.packDescription;
    data['moq'] = this.moq;
    data['categoryId'] = this.categoryId;
    data['packVariant'] = this.packVariant;
    if (this.packColorLabel != null) {
      data['packColorLabel'] =
          this.packColorLabel.map((v) => v.toJson()).toList();
    }
    if (this.headSetInformation != null) {
      data['headSetInformation'] = this.headSetInformation!.toJson();
    }
    if (this.packImages != null) {
      data['packImages'] = this.packImages.map((v) => v.toJson()).toList();
    }
    if (this.packOptions != null) {
      data['packOptions'] = this.packOptions.map((v) => v.toJson()).toList();
    }
    data['__typename'] = this.sTypename;
    return data;
  }
}

class HeadSetInformation {
  late final int setPrice;
  late final int setQuantity;
  late final List<MergeAttribute> mergeAttribute;
  late final String sTypename;

  HeadSetInformation(
      {required this.setPrice,
      required this.setQuantity,
      required this.mergeAttribute,
      required this.sTypename});

  HeadSetInformation.fromJson(Map<String, dynamic> json) {
    setPrice = json['setPrice'];
    setQuantity = json['setQuantity'];
    if (json['mergeAttribute'] != null) {
      mergeAttribute = [];
      json['mergeAttribute'].forEach((v) {
        mergeAttribute.add(new MergeAttribute.fromJson(v));
      });
    }
    sTypename = json['__typename'];
  }

  Map<String, dynamic> toJson() {
    final Map<String, dynamic> data = new Map<String, dynamic>();
    data['setPrice'] = this.setPrice;
    data['setQuantity'] = this.setQuantity;
    if (this.mergeAttribute != null) {
      data['mergeAttribute'] =
          this.mergeAttribute.map((v) => v.toJson()).toList();
    }
    data['__typename'] = this.sTypename;
    return data;
  }
}

class MergeAttribute {
  late final String labelName;
  late final String? fieldSetting;
  late final String fieldValue;
  late final String sTypename;

  MergeAttribute(
      {required this.labelName,
      required this.fieldSetting,
      required this.fieldValue,
      required this.sTypename});

  MergeAttribute.fromJson(Map<String, dynamic> json) {
    labelName = json['labelName'];
    fieldSetting = json['fieldSetting'];
    fieldValue = json['fieldValue'];
    sTypename = json['__typename'];
  }

  Map<String, dynamic> toJson() {
    final Map<String, dynamic> data = new Map<String, dynamic>();
    data['labelName'] = this.labelName;
    data['fieldSetting'] = this.fieldSetting;
    data['fieldValue'] = this.fieldValue;
    data['__typename'] = this.sTypename;
    return data;
  }
}

class PackImages {
  late final String sId;
  late final String packImageName;
  late final String sTypename;

  PackImages(
      {required this.sId,
      required this.packImageName,
      required this.sTypename});

  PackImages.fromJson(Map<String, dynamic> json) {
    sId = json['_id'];
    packImageName = json['packImageName'];
    sTypename = json['__typename'];
  }

  Map<String, dynamic> toJson() {
    final Map<String, dynamic> data = new Map<String, dynamic>();
    data['_id'] = this.sId;
    data['packImageName'] = this.packImageName;
    data['__typename'] = this.sTypename;
    return data;
  }
}

class PackOptions {
  late final String packSetTypeName;
  late final List<PackSetValue> packSetValue;
  late final String sTypename;

  PackOptions(
      {required this.packSetTypeName,
      required this.packSetValue,
      required this.sTypename});

  PackOptions.fromJson(Map<String, dynamic> json) {
    packSetTypeName = json['packSetTypeName'];
    if (json['packSetValue'] != null) {
      packSetValue = [];
      json['packSetValue'].forEach((v) {
        packSetValue.add(new PackSetValue.fromJson(v));
      });
    }
    sTypename = json['__typename'];
  }

  Map<String, dynamic> toJson() {
    final Map<String, dynamic> data = new Map<String, dynamic>();
    data['packSetTypeName'] = this.packSetTypeName;
    if (this.packSetValue != null) {
      data['packSetValue'] = this.packSetValue.map((v) => v.toJson()).toList();
    }
    data['__typename'] = this.sTypename;
    return data;
  }
}

class PackSetValue {
  late final String sId;
  late final List<SkuIds> skuIds;
  late final int count;
  late final int setPrice;
  late final int setQuantity;
  late final int maximumQuantity;
  late final String setLabelName;
  late final String? setColorId;
  late final String? setAppletName;
  late final String sTypename;

  PackSetValue(
      {required this.sId,
      required this.skuIds,
      required this.count,
      required this.setPrice,
      required this.setQuantity,
      required this.maximumQuantity,
      required this.setLabelName,
      required this.setColorId,
      required this.setAppletName,
      required this.sTypename});

  PackSetValue.fromJson(Map<String, dynamic> json) {
    sId = json['_id'];
    if (json['skuIds'] != null) {
      skuIds = [];
      json['skuIds'].forEach((v) {
        skuIds.add(new SkuIds.fromJson(v));
      });
    }
    count = json['count'];
    setPrice = json['setPrice'];
    setQuantity = json['setQuantity'];
    setLabelName = json['setLabelName'];
    maximumQuantity = json['maximumQuantity'];
    setColorId = json['setColorId'];
    setAppletName = json['setAppletName'];
    sTypename = json['__typename'];
  }

  Map<String, dynamic> toJson() {
    final Map<String, dynamic> data = new Map<String, dynamic>();
    data['_id'] = this.sId;
    if (this.skuIds != null) {
      data['skuIds'] = this.skuIds.map((v) => v.toJson()).toList();
    }
    data['count'] = this.count;
    data['setPrice'] = this.setPrice;
    data['setQuantity'] = this.setQuantity;
    data['maximumQuantity'] = this.maximumQuantity;
    data['setLabelName'] = this.setLabelName;
    data['setColorId'] = this.setColorId;
    data['setAppletName'] = this.setAppletName;
    data['__typename'] = this.sTypename;
    return data;
  }
}

class SkuIds {
  late final SkuId? skuId;
  late final int setSKUprice;
  late final String sTypename;

  SkuIds(
      {required this.skuId,
      required this.setSKUprice,
      required this.sTypename});

  SkuIds.fromJson(Map<String, dynamic> json) {
    skuId = json['skuId'] != null ? new SkuId.fromJson(json['skuId']) : null;
    setSKUprice = json['setSKUprice'];
    sTypename = json['__typename'];
  }

  Map<String, dynamic> toJson() {
    final Map<String, dynamic> data = new Map<String, dynamic>();
    if (this.skuId != null) {
      data['skuId'] = this.skuId!.toJson();
    }
    data['setSKUprice'] = this.setSKUprice;
    data['__typename'] = this.sTypename;
    return data;
  }
}

class SkuId {
  late final String sId;
  late final String sku;
  late final int b2bSellingPrice;
  late final String sTypename;

  SkuId(
      {required this.sId,
      required this.sku,
      required this.b2bSellingPrice,
      required this.sTypename});

  SkuId.fromJson(Map<String, dynamic> json) {
    sId = json['_id'];
    sku = json['sku'];
    b2bSellingPrice = json['b2bSellingPrice'];
    sTypename = json['__typename'];
  }

  Map<String, dynamic> toJson() {
    final Map<String, dynamic> data = new Map<String, dynamic>();
    data['_id'] = this.sId;
    data['sku'] = this.sku;
    data['b2bSellingPrice'] = this.b2bSellingPrice;
    data['__typename'] = this.sTypename;
    return data;
  }
}

CheckCancelCategoryForDetailPage checkCancelCategoryForDetailPageJson(
        dynamic str) =>
    (CheckCancelCategoryForDetailPage.fromJson(str));

class CheckCancelCategoryForDetailPage {
  late final bool? isReturnable;
  late final String? sTypename;

  CheckCancelCategoryForDetailPage(
      {required this.isReturnable, required this.sTypename});

  CheckCancelCategoryForDetailPage.fromJson(Map<String, dynamic> json) {
    isReturnable = json['isReturnable'];
    sTypename = json['__typename'];
  }

  Map<String, dynamic> toJson() {
    final Map<String, dynamic> data = new Map<String, dynamic>();
    data['isReturnable'] = this.isReturnable;
    data['__typename'] = this.sTypename;
    return data;
  }
}

GetDelhiveryServiceability delhiveryServiceabilityJson(dynamic str) =>
    (GetDelhiveryServiceability.fromJson(str));

class GetDelhiveryServiceability {
  late final bool? prePaid;
  late final bool? cash;
  late final bool? pickup;
  late final bool? cod;
  late final String? estimate;
  late final String? sTypename;

  GetDelhiveryServiceability(
      {required this.prePaid,
      required this.cash,
      required this.pickup,
      required this.cod,
      required this.estimate,
      required this.sTypename});

  GetDelhiveryServiceability.fromJson(Map<String, dynamic> json) {
    prePaid = json['pre_paid'];
    cash = json['cash'];
    pickup = json['pickup'];
    cod = json['cod'];
    estimate = json['estimate'];
    sTypename = json['__typename'];
  }

  Map<String, dynamic> toJson() {
    final Map<String, dynamic> data = new Map<String, dynamic>();
    data['pre_paid'] = this.prePaid;
    data['cash'] = this.cash;
    data['pickup'] = this.pickup;
    data['cod'] = this.cod;
    data['estimate'] = this.estimate;
    data['__typename'] = this.sTypename;
    return data;
  }
}

List<SimilarPack> similarPackFromJson(dynamic str) =>
    List<SimilarPack>.from(str.map((x) => SimilarPack.fromJson(x)));

class SimilarPack {
  late final String? sId;
  late final String? packName;
  late final String? packId;
  late final String? setId;
  late final String? packImage;
  late final int? setPrice;
  late final String? sTypename;

  SimilarPack(
      {required this.sId,
      required this.packName,
      required this.packId,
      required this.setId,
      required this.packImage,
      required this.setPrice,
      required this.sTypename});

  SimilarPack.fromJson(Map<String, dynamic> json) {
    sId = json['_id'];
    packName = json['packName'];
    packId = json['packId'];
    setId = json['setId'];
    packImage = json['packImage'];
    setPrice = json['setPrice'];
    sTypename = json['__typename'];
  }

  Map<String, dynamic> toJson() {
    final Map<String, dynamic> data = new Map<String, dynamic>();
    data['_id'] = this.sId;
    data['packName'] = this.packName;
    data['packId'] = this.packId;
    data['setId'] = this.setId;
    data['packImage'] = this.packImage;
    data['setPrice'] = this.setPrice;
    data['__typename'] = this.sTypename;
    return data;
  }
}

List<LocalRecentPack> localRecentPackFromJson(dynamic str) =>
    List<LocalRecentPack>.from(str.map((x) => LocalRecentPack.fromJson(x)));

class LocalRecentPack {
  late final String? sId;
  late final String? packName;
  late final String? packId;
  late final String? setId;
  late final String? packImage;
  late final int? setPrice;
  late final String? sTypename;

  LocalRecentPack(
      {required this.sId,
      required this.packName,
      required this.packId,
      required this.setId,
      required this.packImage,
      required this.setPrice,
      required this.sTypename});

  LocalRecentPack.fromJson(Map<String, dynamic> json) {
    sId = json['_id'];
    packName = json['packName'];
    packId = json['packId'];
    setId = json['setId'];
    packImage = json['packImage'];
    setPrice = json['setPrice'];
    sTypename = json['__typename'];
  }

  Map<String, dynamic> toJson() {
    final Map<String, dynamic> data = new Map<String, dynamic>();
    data['_id'] = this.sId;
    data['packName'] = this.packName;
    data['packId'] = this.packId;
    data['setId'] = this.setId;
    data['packImage'] = this.packImage;
    data['setPrice'] = this.setPrice;
    data['__typename'] = this.sTypename;
    return data;
  }
}
